==> iotfleetwise-2.18.18-sources.jar: software/amazon/awssdk/services/iotfleetwise/paginators/ListDecoderManifestSignalsPublisher.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.iotfleetwise.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;
import org.reactivestreams.Subscriber;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.async.SdkPublisher;
import software.amazon.awssdk.core.pagination.async.AsyncPageFetcher;
import software.amazon.awssdk.core.pagination.async.PaginatedItemsPublisher;
import software.amazon.awssdk.core.pagination.async.ResponsesSubscription;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.iotfleetwise.IoTFleetWiseAsyncClient;
import software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest;
import software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse;
import software.amazon.awssdk.services.iotfleetwise.model.SignalDecoder;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.iotfleetwise.IoTFleetWiseAsyncClient#listDecoderManifestSignalsPaginator(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest)}
 * operation which is a paginated operation. This class is a type of {@link org.reactivestreams.Publisher} which can be
 * used to provide a sequence of
 * {@link software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse} response pages as per
 * demand from the subscriber.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. If there are errors in your request, you will see the failures
 * only after you start streaming the data. The subscribe method should be called as a request to start streaming data.
 * For more info, see {@link org.reactivestreams.Publisher#subscribe(org.reactivestreams.Subscriber)}. Each call to the
 * subscribe method will result in a new {@link org.reactivestreams.Subscription} i.e., a new contract to stream data
 * from the starting request.
 * </p>
 *
 * <p>
 * The following are few ways to use the response class:
 * </p>
 * 1) Using the subscribe helper method
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iotfleetwise.paginators.ListDecoderManifestSignalsPublisher publisher = client.listDecoderManifestSignalsPaginator(request);
 * CompletableFuture<Void> future = publisher.subscribe(res -> { // Do something with the response });
 * future.get();
 * }
 * </pre>
 *
 * 2) Using a custom subscriber
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iotfleetwise.paginators.ListDecoderManifestSignalsPublisher publisher = client.listDecoderManifestSignalsPaginator(request);
 * publisher.subscribe(new Subscriber<software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse>() {
 * 
 * public void onSubscribe(org.reactivestreams.Subscriber subscription) { //... };
 * 
 * 
 * public void onNext(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse response) { //... };
 * });}
 * </pre>
 * 
 * As the response is a publisher, it can work well with third party reactive streams implementations like RxJava2.
 * <p>
 * <b>Please notice that the configuration of maxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listDecoderManifestSignals(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListDecoderManifestSignalsPublisher implements SdkPublisher<ListDecoderManifestSignalsResponse> {
    private final IoTFleetWiseAsyncClient client;

    private final ListDecoderManifestSignalsRequest firstRequest;

    private final AsyncPageFetcher nextPageFetcher;

    private boolean isLastPage;

    public ListDecoderManifestSignalsPublisher(IoTFleetWiseAsyncClient client, ListDecoderManifestSignalsRequest firstRequest) {
        this(client, firstRequest, false);
    }

    private ListDecoderManifestSignalsPublisher(IoTFleetWiseAsyncClient client, ListDecoderManifestSignalsRequest firstRequest,
            boolean isLastPage) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.isLastPage = isLastPage;
        this.nextPageFetcher = new ListDecoderManifestSignalsResponseFetcher();
    }

    @Override
    public void subscribe(Subscriber<? super ListDecoderManifestSignalsResponse> subscriber) {
        subscriber.onSubscribe(ResponsesSubscription.builder().subscriber(subscriber).nextPageFetcher(nextPageFetcher).build());
    }

    /**
     * Returns a publisher that can be used to get a stream of data. You need to subscribe to the publisher to request
     * the stream of data. The publisher has a helper forEach method that takes in a {@link java.util.function.Consumer}
     * and then applies that consumer to each response returned by the service.
     */
    public final SdkPublisher<SignalDecoder> signalDecoders() {
        Function<ListDecoderManifestSignalsResponse, Iterator<SignalDecoder>> getIterator = response -> {
            if (response != null && response.signalDecoders() != null) {
                return response.signalDecoders().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsPublisher.builder().nextPageFetcher(new ListDecoderManifestSignalsResponseFetcher())
                .iteratorFunction(getIterator).isLastPage(isLastPage).build();
    }

    private class ListDecoderManifestSignalsResponseFetcher implements AsyncPageFetcher<ListDecoderManifestSignalsResponse> {
        @Override
        public boolean hasNextPage(final ListDecoderManifestSignalsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public CompletableFuture<ListDecoderManifestSignalsResponse> nextPage(
                final ListDecoderManifestSignalsResponse previousPage) {
            if (previousPage == null) {
                return client.listDecoderManifestSignals(firstRequest);
            }
            return client.listDecoderManifestSignals(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> iotfleetwise-2.20.133-sources.jar: software/amazon/awssdk/services/iotfleetwise/paginators/ListDecoderManifestSignalsPublisher.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.iotfleetwise.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;
import org.reactivestreams.Subscriber;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.async.SdkPublisher;
import software.amazon.awssdk.core.pagination.async.AsyncPageFetcher;
import software.amazon.awssdk.core.pagination.async.PaginatedItemsPublisher;
import software.amazon.awssdk.core.pagination.async.ResponsesSubscription;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.iotfleetwise.IoTFleetWiseAsyncClient;
import software.amazon.awssdk.services.iotfleetwise.internal.UserAgentUtils;
import software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest;
import software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse;
import software.amazon.awssdk.services.iotfleetwise.model.SignalDecoder;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.iotfleetwise.IoTFleetWiseAsyncClient#listDecoderManifestSignalsPaginator(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest)}
 * operation which is a paginated operation. This class is a type of {@link org.reactivestreams.Publisher} which can be
 * used to provide a sequence of
 * {@link software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse} response pages as per
 * demand from the subscriber.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. If there are errors in your request, you will see the failures
 * only after you start streaming the data. The subscribe method should be called as a request to start streaming data.
 * For more info, see {@link org.reactivestreams.Publisher#subscribe(org.reactivestreams.Subscriber)}. Each call to the
 * subscribe method will result in a new {@link org.reactivestreams.Subscription} i.e., a new contract to stream data
 * from the starting request.
 * </p>
 *
 * <p>
 * The following are few ways to use the response class:
 * </p>
 * 1) Using the subscribe helper method
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iotfleetwise.paginators.ListDecoderManifestSignalsPublisher publisher = client.listDecoderManifestSignalsPaginator(request);
 * CompletableFuture<Void> future = publisher.subscribe(res -> { // Do something with the response });
 * future.get();
 * }
 * </pre>
 *
 * 2) Using a custom subscriber
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iotfleetwise.paginators.ListDecoderManifestSignalsPublisher publisher = client.listDecoderManifestSignalsPaginator(request);
 * publisher.subscribe(new Subscriber<software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse>() {
 * 
 * public void onSubscribe(org.reactivestreams.Subscriber subscription) { //... };
 * 
 * 
 * public void onNext(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsResponse response) { //... };
 * });}
 * </pre>
 * 
 * As the response is a publisher, it can work well with third party reactive streams implementations like RxJava2.
 * <p>
 * <b>Please notice that the configuration of maxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listDecoderManifestSignals(software.amazon.awssdk.services.iotfleetwise.model.ListDecoderManifestSignalsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListDecoderManifestSignalsPublisher implements SdkPublisher<ListDecoderManifestSignalsResponse> {
    private final IoTFleetWiseAsyncClient client;

    private final ListDecoderManifestSignalsRequest firstRequest;

    private final AsyncPageFetcher nextPageFetcher;

    private boolean isLastPage;

    public ListDecoderManifestSignalsPublisher(IoTFleetWiseAsyncClient client, ListDecoderManifestSignalsRequest firstRequest) {
        this(client, firstRequest, false);
    }

    private ListDecoderManifestSignalsPublisher(IoTFleetWiseAsyncClient client, ListDecoderManifestSignalsRequest firstRequest,
            boolean isLastPage) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.isLastPage = isLastPage;
        this.nextPageFetcher = new ListDecoderManifestSignalsResponseFetcher();
    }

    @Override
    public void subscribe(Subscriber<? super ListDecoderManifestSignalsResponse> subscriber) {
        subscriber.onSubscribe(ResponsesSubscription.builder().subscriber(subscriber).nextPageFetcher(nextPageFetcher).build());
    }

    /**
     * Returns a publisher that can be used to get a stream of data. You need to subscribe to the publisher to request
     * the stream of data. The publisher has a helper forEach method that takes in a {@link java.util.function.Consumer}
     * and then applies that consumer to each response returned by the service.
     */
    public final SdkPublisher<SignalDecoder> signalDecoders() {
        Function<ListDecoderManifestSignalsResponse, Iterator<SignalDecoder>> getIterator = response -> {
            if (response != null && response.signalDecoders() != null) {
                return response.signalDecoders().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsPublisher.builder().nextPageFetcher(new ListDecoderManifestSignalsResponseFetcher())
                .iteratorFunction(getIterator).isLastPage(isLastPage).build();
    }

    private class ListDecoderManifestSignalsResponseFetcher implements AsyncPageFetcher<ListDecoderManifestSignalsResponse> {
        @Override
        public boolean hasNextPage(final ListDecoderManifestSignalsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public CompletableFuture<ListDecoderManifestSignalsResponse> nextPage(
                final ListDecoderManifestSignalsResponse previousPage) {
            if (previousPage == null) {
                return client.listDecoderManifestSignals(firstRequest);
            }
            return client.listDecoderManifestSignals(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
